.. _declarative_config_toplevel:

================================
Mapping Classes with Declarative
================================

The Declarative mapping style is the primary style of mapping that is used
with SQLAlchemy.   See the section :ref:`orm_declarative_mapping` for the
top level introduction.


.. toctree::
    :maxdepth: 3

    declarative_tables
    declarative_config
    declarative_mixins
